==> haskell-cryptonite-conduit-0.2.0-17-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cryptonite-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptonite-conduit
version: 0.2.0
id: cryptonite-conduit-0.2.0-DGa6Ybn3yZb9wzcq7zM2LR
key: cryptonite-conduit-0.2.0-DGa6Ybn3yZb9wzcq7zM2LR
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: https://github.com/haskell-crypto/cryptonite-conduit
synopsis: cryptonite conduit
description:
    Conduit bridge for cryptonite
    .
    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.
category: Cryptography, Conduit
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.MAC.HMAC.Conduit Crypto.Hash.Conduit
abi: 28ffc76f034b3b941784699430941ef0
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cryptonite-conduit-0.2.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/cryptonite-conduit-0.2.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/cryptonite-conduit-0.2.0
hs-libraries: HScryptonite-conduit-0.2.0-DGa6Ybn3yZb9wzcq7zM2LR
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    conduit-1.2.10-JpwcbBZZrSj1n2q4Mh3BJS
    conduit-extra-1.1.16-LbHEhSYrKrIKl2iEItQ5UA
    cryptonite-0.23-IZJ66Y8jjDgmndLH4VfVr
    memory-0.14.5-GKVoAxUgmX27c6UFr57XrL
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-cryptonite-conduit/html/cryptonite-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptonite-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptonite-conduit-0.2.0-18-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cryptonite-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptonite-conduit
version: 0.2.0
id: cryptonite-conduit-0.2.0-5Te5BFAuVecCSbC6rGmtOh
key: cryptonite-conduit-0.2.0-5Te5BFAuVecCSbC6rGmtOh
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: https://github.com/haskell-crypto/cryptonite-conduit
synopsis: cryptonite conduit
description:
    Conduit bridge for cryptonite
    .
    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.
category: Cryptography, Conduit
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.MAC.HMAC.Conduit Crypto.Hash.Conduit
abi: ff7e6bdd75204018ad9ff7524d5ed1e3
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cryptonite-conduit-0.2.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/cryptonite-conduit-0.2.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/cryptonite-conduit-0.2.0
hs-libraries: HScryptonite-conduit-0.2.0-5Te5BFAuVecCSbC6rGmtOh
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    conduit-1.2.10-Jh04T8HFIqp3EspViruWGc
    conduit-extra-1.1.16-CBMZFGMUTTf2i7AtanQHuU
    cryptonite-0.23-IZJ66Y8jjDgmndLH4VfVr
    memory-0.14.5-GKVoAxUgmX27c6UFr57XrL
    resourcet-1.1.9-LttKXnENmd16hW52fqUDxA transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-cryptonite-conduit/html/cryptonite-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptonite-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
